==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseAlertLikeDescriptionMetadata } from "./WebBaseAlertLikeDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
export let WebSnackbarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSnackbarDescriptionMetadata extends Base {
        static b(a) {
            if (WebSnackbarDescriptionMetadata.a == null) {
                WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
            }
            if (a.k(WebSnackbarDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSnackbarDescriptionMetadata.a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseAlertLikeDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Snackbar");
            a.item("__tagNameWC", "String:igc-snackbar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("ActionText", "String");
            a.item("ActionRef", "EventRef::action");
        }
        static d(a) {
            WebSnackbarDescriptionMetadata.b(a);
            a.ad("WebSnackbar", () => new WebSnackbarDescription());
            a.ac("WebSnackbar", WebSnackbarDescriptionMetadata.a);
        }
    }
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebSnackbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VoidEventArgsDescriptionMetadata } from "./VoidEventArgsDescriptionMetadata";
import { WebBaseAlertLikeDescriptionMetadata } from "./WebBaseAlertLikeDescriptionMetadata";
import { WebSnackbarDescription } from "./WebSnackbarDescription";
/**
 * @hidden
 */
export let WebSnackbarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSnackbarDescriptionMetadata extends Base {
        static b(a) {
            if (WebSnackbarDescriptionMetadata.a == null) {
                WebSnackbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSnackbarDescriptionMetadata.c(WebSnackbarDescriptionMetadata.a);
            }
            if (a.k(WebSnackbarDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSnackbarDescriptionMetadata.a);
            VoidEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseAlertLikeDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Snackbar");
            a.item("__tagNameWC", "String:igc-snackbar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("ActionText", "String");
            a.item("ActionRef", "EventRef::action");
        }
        static d(a) {
            WebSnackbarDescriptionMetadata.b(a);
            a.ae("WebSnackbar", () => new WebSnackbarDescription());
            a.ad("WebSnackbar", WebSnackbarDescriptionMetadata.a);
        }
    }
    WebSnackbarDescriptionMetadata.$t = markType(WebSnackbarDescriptionMetadata, 'WebSnackbarDescriptionMetadata');
    WebSnackbarDescriptionMetadata.a = null;
    return WebSnackbarDescriptionMetadata;
})();
